@@ -211,3 +211,10 @@ class Post(BaseUserContentModel):
         except ValueError: # catch avatar url does not exist
             avatar_url = '/img/avatars/default.jpg'
         return avatar_url
+
+    @cached_property
+    def parent(self):
+        """ 
+        Shortcut to parent topic. Makes life easier for activity monitor.
+        """
+        return self.topic
